==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/is.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Dagatal",
    "%s has published the calendar \"%s\"" : "%s gaf út dagatalið \"%s\"",
    "Too many redirects. Aborting ..." : "Of margar endurbeiningar. Hætti við ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Fjartengdi þjónninn gaf ekki aðgang að dagatalinu (HTTP {%s} villa)",
    "Error connecting to remote server" : "Villa við tengingu við fjartengdan þjón",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Villa við beiðni um tilfang á fjartengdum þjóni. Þetta gæti stafað af misræmi í skilríkjum (certificate)",
    "Error requesting resource on remote server" : "Villa við beiðni um tilfang á fjartengdum þjóni",
    "Individual" : "Einstaklingur",
    "Group" : "Hópur",
    "Resource" : "Tilfang",
    "Room" : "Herbergi",
    "Unknown" : "Óþekkt",
    "Required" : "þetta þarf",
    "Optional" : "Valkvætt",
    "Does not attend" : "Mætir ekki",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Þú ert á óþekktu tímabelti ({tz}), fell aftur á UTC-tíma",
    "Please create a calendar first." : "Búðu fyrst til dagatal.",
    "New event" : "Nýr atburður",
    "CalDAV address for clients" : "CalDAV-vistfang fyrir biðlara",
    "Error saving WebCal-calendar" : "Villa við að vista WebCal-dagatal",
    "WebDAV address for subscriptions" : "WebDAV-vistfang fyrir áskriftir",
    "EMail has been sent." : "Tölvupósturinn var sendur.",
    "There was an issue while sending your EMail." : "Það kom upp vandamál við að senda tölvupóstinn þinn.",
    "group" : "hópur",
    "Details" : "Nánar",
    "Attendees" : "Þáttakendur",
    "Reminders" : "Áminningar",
    "Repeating" : "Endurtekning",
    "When shared show full event" : "Þegar er deilt, birta allan atburð",
    "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
    "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
    "Confirmed" : "Staðfest",
    "Tentative" : "Bráðabirgða",
    "Cancelled" : "Hætt við",
    "Please add a title!" : "Settu inn titil!",
    "Please select a calendar!" : "Veldu dagatal!",
    "The event ends before it starts!" : "Atburðurinn endar áður en hann byrjar!",
    "Global" : "Almennt",
    "None" : "Ekkert",
    "Every day" : "Daglega",
    "Every week" : "Vikulega",
    "Every month" : "Mánuður",
    "Every year" : "Árlega",
    "never" : "aldrei",
    "after" : "eftir",
    "How about getting started by importing some calendars?" : "Hvernig væri að byrja á því að flytja inn einhver dagatöl?",
    "At time of event" : "Þegar atburður á sér stað",
    "5 minutes before" : "5 mínútum fyrir",
    "10 minutes before" : "10 mínútum fyrir",
    "15 minutes before" : "15 mínútum fyrir",
    "30 minutes before" : "30 mínútum fyrir",
    "1 hour before" : "1 klukkustund fyrir ",
    "2 hours before" : "2 klukkustundum fyrir",
    "Custom" : "Sérsniðið",
    "Audio" : "Hljóð",
    "E Mail" : "Tölvupóstur",
    "Pop up" : "Sprettgluggi",
    "sec" : "sek",
    "min" : "mín",
    "hours" : "klukkustundir",
    "days" : "daga",
    "week" : "vika",
    "before" : "fyrir",
    "start" : "upphaf",
    "end" : "endir",
    "Editing reminders of unknown type not supported." : "Breytingar á áminningum með óþekktu sniði er ekki stutt.",
    "Week {number} of {year}" : "Vika {number},{year}",
    "Successfully imported" : "Innflutningur tókst",
    "Partially imported, 1 failure" : "Flutt inn að hluta, 1 villa",
    "Partially imported, {n} failures" : "Flutt inn að hluta, {n} villur",
    "Audio alarm" : "Hljóðáminning",
    "Pop-up" : "Sprettgluggi",
    "E-Mail" : "Tölvupóstfang",
    "{type} {time} before the event starts" : "{type} {time} áður en atburður hefst",
    "{type} {time} before the event ends" : "{type} {time} áður en atburður endar",
    "{type} {time} after the event starts" : "{type} {time} eftir að atburður hefst",
    "{type} {time} after the event ends" : "{type} {time} eftir að atburður endar",
    "{type} at the event's start" : "{type} við upphafstíma atburðar",
    "{type} at the event's end" : "{type} við endatíma atburðar",
    "{type} at {time}" : "{type} klukkan {time}",
    "{calendar} shared by {owner}" : "{calendar} deilt af {owner}",
    "Please enter a valid WebCal-URL" : "Skráðu inn gilda WebCal-slóð",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Alvarleg villa í webcal-milliþjóni. Hafðu samband við kerfisstjóra.",
    "Title of the Event" : "Titill atburðar",
    "Starts" : "Byrjar",
    "Ends" : "Endar",
    "All day Event" : "Heilsdagsviðburður",
    "Delete" : "Eyða",
    "Cancel" : "Hætta við",
    "More ..." : "Meira...",
    "Create" : "Búa til",
    "Update" : "Uppfæra",
    "Close" : "Loka",
    "Location" : "Staðsetning",
    "Description" : "Lýsing",
    "Event status" : "Staða atburðar",
    "Visibility when sharing" : "Sýnileiki við deilingu",
    "Export" : "Flytja út",
    "%s has published the calendar %s" : "%s gaf út dagatalið %s",
    "Hello," : "Halló,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Við vildum láta þig vita að %s gaf út dagatalið {boldstart}%s{boldend}.",
    "Click here to access it" : "Smelltu hér til að nálgast það",
    "Cheers!" : "Til hamingju!",
    "We wanted to inform you that %s has published the calendar %s." : "Við vildum láta þig vita að s gaf út dagatalið %s.",
    "Click on the link below to access it" : "Smelltu á tengilinn hér fyrir neðan til að nálgast það",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Vegna villu í frumkóða, verður dagatalið ekki nothæft með stuðningi við pípaða vinnslu tilfanga.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Hafðu samband við kerfisstjóra og biddu þá/hann um að gera \"asset-pipeline.enabled\" stillingakostinn óvirkann.",
    "Day" : "Dagur",
    "Week" : "Vika",
    "Month" : "Mánuður",
    "Today" : "Í dag",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Sumir atburðir í þessu dagatali eru gallaðir. Athugaðu JS-stjórnborðið til að sjá frekari upplýsingar.",
    "Share Calendar" : "Deila dagatali",
    "Shared" : "Deilt",
    "More" : "Meira",
    "Edit" : "Breyta",
    "Link" : "Tengill",
    "iCal link" : "iCal-tengill",
    "Download" : "Sækja",
    "Share with users or groups" : "Deila með notendum eða hópum",
    "can edit" : "getur breytt",
    "Share link" : "Deila tengli",
    "Public access" : "Opinber aðgangur",
    "Email link to person" : "Senda veftengil í tölvupósti til notanda",
    "Send" : "Senda",
    "New Calendar" : "Nýtt dagatal",
    "Name" : "Heiti",
    "New Subscription" : "Ný áskrift",
    "Go back" : "Fara til baka",
    "Go forward" : "Fara áfram",
    "Calendar does not exist" : "Dagatalið er ekki til",
    "Maybe you got a wrong link or the calendar was unshared?" : "Hugsanlega ertu með rangan tengil eða að deilingu var hætt á dagatalinu?",
    "Edit event" : "Breyta atburði",
    "Delete Event" : "Eyða atburði",
    "Save Event" : "Vista atburð",
    "Time" : "Tími",
    "Type" : "Tegund",
    "Relative" : "Hlutfallslegt",
    "Absolute" : "Algilt",
    "Repeat" : "Endurtaka",
    "times every" : "sinnum hverjar",
    "Add" : "Bæta við",
    "E-Mail address of attendee" : "Tölvupóstfang þátttakanda",
    "Please add your email address in the personal settings in order to add attendees." : "Settu inn tölvupóstfangið þitt í einkastillingum þínum svo að þú getir bætt við þátttakendum.",
    "from" : "frá",
    "to" : "til",
    "This event's repeating rule is not supported yet." : "Endurtekningarregla þessa atburðar er ekki ennþá studd.",
    "Support for advanced rules will be added with subsequent updates." : "Stuðningi við flóknari reglur verður bætt við í væntanlegum uppfærslum.",
    "Reset repeating rule" : "Endursetja endurtekningarreglu",
    "Repeat every ..." : "Endurtaka ...",
    "end repeat ..." : "enda endurtekningu ...",
    "times" : "sinnum",
    "Import Calendars" : "Flytja inn dagatöl",
    "Import canceled" : "Hætt við innflutning",
    "Analyzing calendar" : "Greini dagatal",
    "The file contains objects incompatible with the selected calendar" : "Skráin inniheldur atriði sem ekki eru samhæfanleg völdu dagatali",
    "New calendar" : "Nýtt dagatal",
    "File is empty" : "Skráin er tóm",
    "Import scheduled" : "Áætlaður innflutningur",
    "%s shared the calendar <strong>%s</strong> with you" : "%s deildi dagatalinu <strong>%s</strong> með þér",
    "Embed" : "Ívefja",
    "IFrame to integrate" : "Iframe-rammi til að samþætta",
    "Publish URL" : "Gefa út slóð",
    "Settings & import" : "Stillingar og innflutningur",
    "Skip simple event editor" : "Sleppa einföldum atburðaritli",
    "Show week numbers" : "Sýna vikunúmer",
    "Import calendar" : "Flytja inn dagatal",
    "No Calendars selected for import" : "Engin dagatöl valin til innflutnings",
    "Primary CalDAV address" : "Aðal-CalDAV-vistfang",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-vistfang",
    "Subscribe" : "Gerast áskrifandi"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/is.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Dagatal",
    "%s has published the calendar »%s«" : "%s gaf út dagatalið »%s«",
    "Hello," : "Halló,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Við vildum láta þig vita að %s gaf út dagatalið »%s«.",
    "Open »%s«" : "Opna »%s«",
    "Cheers!" : "Til hamingju!",
    "Recipient" : "Viðtakandi",
    "Too many redirects. Aborting ..." : "Of margar endurbeiningar. Hætti við ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Fjartengdi þjónninn gaf ekki aðgang að dagatalinu (HTTP {%s} villa)",
    "Error connecting to remote server" : "Villa við tengingu við fjartengdan þjón",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Villa við beiðni um tilfang á fjartengdum þjóni. Þetta gæti stafað af misræmi í skilríkjum (certificate)",
    "Error requesting resource on remote server" : "Villa við beiðni um tilfang á fjartengdum þjóni",
    "Individual" : "Einstaklingur",
    "Group" : "Hópur",
    "Resource" : "Tilfang",
    "Room" : "Herbergi",
    "Unknown" : "Óþekkt",
    "Required" : "þetta þarf",
    "Optional" : "Valkvætt",
    "Does not attend" : "Mætir ekki",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Þú ert á óþekktu tímabelti ({tz}), fell aftur á UTC-tíma",
    "Please create a calendar first." : "Búðu fyrst til dagatal.",
    "New event" : "Nýr atburður",
    "CalDAV address for clients" : "CalDAV-vistfang fyrir biðlara",
    "Error saving WebCal-calendar" : "Villa við að vista WebCal-dagatal",
    "WebDAV address for subscriptions" : "WebDAV-vistfang fyrir áskriftir",
    "Email has been sent." : "Tölvupósturinn var sendur.",
    "There was an issue while sending your email." : "Það kom upp vandamál við að senda tölvupóstinn þinn.",
    "group" : "hópur",
    "Details" : "Nánar",
    "Attendees" : "Þáttakendur",
    "Reminders" : "Áminningar",
    "Repeating" : "Endurtekning",
    "When shared show full event" : "Þegar er deilt, birta allan atburð",
    "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
    "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
    "Confirmed" : "Staðfest",
    "Tentative" : "Bráðabirgða",
    "Cancelled" : "Hætt við",
    "Please add a title." : "Settu inn titil.",
    "Please select a calendar." : "Veldu dagatal.",
    "The event can not end before it starts." : "Atburðurinn má ekki enda áður en hann byrjar.",
    "Global" : "Almennt",
    "None" : "Ekkert",
    "Every day" : "Daglega",
    "Every week" : "Vikulega",
    "Every month" : "Mánuður",
    "Every year" : "Árlega",
    "never" : "aldrei",
    "after" : "eftir",
    "How about getting started by importing some calendars?" : "Hvernig væri að byrja á því að flytja inn einhver dagatöl?",
    "At time of event" : "Þegar atburður á sér stað",
    "5 minutes before" : "5 mínútum fyrir",
    "10 minutes before" : "10 mínútum fyrir",
    "15 minutes before" : "15 mínútum fyrir",
    "30 minutes before" : "30 mínútum fyrir",
    "1 hour before" : "1 klukkustund fyrir ",
    "2 hours before" : "2 klukkustundum fyrir",
    "Custom" : "Sérsniðið",
    "Audio" : "Hljóð",
    "Email" : "Tölvupóstur",
    "Pop-up" : "Sprettgluggi",
    "sec" : "sek",
    "min" : "mín",
    "hours" : "klukkustundir",
    "days" : "daga",
    "week" : "vika",
    "before" : "fyrir",
    "start" : "upphaf",
    "end" : "endir",
    "Editing reminders of unknown type not supported." : "Breytingar á áminningum með óþekktu sniði er ekki stutt.",
    "Week {number} of {year}" : "Vika {number},{year}",
    "Successfully imported" : "Innflutningur tókst",
    "Partially imported, 1 failure" : "Flutt inn að hluta, 1 villa",
    "Partially imported, {n} failures" : "Flutt inn að hluta, {n} villur",
    "Audio alarm" : "Hljóðáminning",
    "{type} {time} before the event starts" : "{type} {time} áður en atburður hefst",
    "{type} {time} before the event ends" : "{type} {time} áður en atburður endar",
    "{type} {time} after the event starts" : "{type} {time} eftir að atburður hefst",
    "{type} {time} after the event ends" : "{type} {time} eftir að atburður endar",
    "{type} at the event's start" : "{type} við upphafstíma atburðar",
    "{type} at the event's end" : "{type} við endatíma atburðar",
    "{type} at {time}" : "{type} klukkan {time}",
    "{calendar} shared by {owner}" : "{calendar} deilt af {owner}",
    "Please enter a valid WebCal-URL" : "Skráðu inn gilda WebCal-slóð",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Alvarleg villa í webcal-milliþjóni. Hafðu samband við kerfisstjóra.",
    "Title of the Event" : "Titill atburðar",
    "Starts" : "Byrjar",
    "Ends" : "Endar",
    "All day Event" : "Heilsdagsviðburður",
    "Delete" : "Eyða",
    "Cancel" : "Hætta við",
    "More ..." : "Meira...",
    "Create" : "Búa til",
    "Update" : "Uppfæra",
    "Close" : "Loka",
    "Location" : "Staðsetning",
    "Description" : "Lýsing",
    "Event status" : "Staða atburðar",
    "Visibility when sharing" : "Sýnileiki við deilingu",
    "Export" : "Flytja út",
    "%s has published the calendar %s" : "%s gaf út dagatalið %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Við vildum láta þig vita að %s gaf út dagatalið {boldstart}%s{boldend}.",
    "Click here to access it" : "Smelltu hér til að nálgast það",
    "We wanted to inform you that %s has published the calendar %s." : "Við vildum láta þig vita að s gaf út dagatalið %s.",
    "Click on the link below to access it" : "Smelltu á tengilinn hér fyrir neðan til að nálgast það",
    "Day" : "Dagur",
    "Week" : "Vika",
    "Month" : "Mánuður",
    "Today" : "Í dag",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Sumir atburðir í þessu dagatali eru gallaðir. Athugaðu JS-stjórnborðið til að sjá frekari upplýsingar.",
    "Share Calendar" : "Deila dagatali",
    "Shared" : "Deilt",
    "More" : "Meira",
    "Edit" : "Breyta",
    "Link" : "Tengill",
    "iCal link" : "iCal-tengill",
    "Download" : "Sækja",
    "Share with users or groups" : "Deila með notendum eða hópum",
    "can edit" : "getur breytt",
    "Share link" : "Deila tengli",
    "Public access" : "Opinber aðgangur",
    "Email link to person" : "Senda veftengil í tölvupósti til notanda",
    "Send" : "Senda",
    "New Calendar" : "Nýtt dagatal",
    "Name" : "Heiti",
    "New Subscription" : "Ný áskrift",
    "Go back" : "Fara til baka",
    "Go forward" : "Fara áfram",
    "Calendar does not exist" : "Dagatalið er ekki til",
    "Maybe you got a wrong link or the calendar was unshared?" : "Hugsanlega ertu með rangan tengil eða að deilingu var hætt á dagatalinu?",
    "Edit event" : "Breyta atburði",
    "Delete Event" : "Eyða atburði",
    "Save Event" : "Vista atburð",
    "Time" : "Tími",
    "Type" : "Tegund",
    "Relative" : "Hlutfallslegt",
    "Absolute" : "Algilt",
    "Repeat" : "Endurtaka",
    "times every" : "sinnum hverjar",
    "Add" : "Bæta við",
    "Email address of attendee" : "Tölvupóstfang þátttakanda",
    "Please add your email address in the personal settings in order to add attendees." : "Settu inn tölvupóstfangið þitt í einkastillingum þínum svo að þú getir bætt við þátttakendum.",
    "from" : "frá",
    "to" : "til",
    "This event's repeating rule is not supported yet." : "Endurtekningarregla þessa atburðar er ekki ennþá studd.",
    "Support for advanced rules will be added with subsequent updates." : "Stuðningi við flóknari reglur verður bætt við í væntanlegum uppfærslum.",
    "Reset repeating rule" : "Endursetja endurtekningarreglu",
    "Repeat every ..." : "Endurtaka ...",
    "end repeat ..." : "enda endurtekningu ...",
    "times" : "sinnum",
    "Import Calendars" : "Flytja inn dagatöl",
    "Import canceled" : "Hætt við innflutning",
    "Analyzing calendar" : "Greini dagatal",
    "The file contains objects incompatible with the selected calendar" : "Skráin inniheldur atriði sem ekki eru samhæfanleg völdu dagatali",
    "New calendar" : "Nýtt dagatal",
    "File is empty" : "Skráin er tóm",
    "Import scheduled" : "Áætlaður innflutningur",
    "%s shared the calendar <strong>%s</strong> with you" : "%s deildi dagatalinu <strong>%s</strong> með þér",
    "Embed" : "Ívefja",
    "Iframe to integrate" : "Iframe-rammi til að samþætta",
    "Publish URL" : "Gefa út slóð",
    "Settings & import" : "Stillingar og innflutningur",
    "Skip simple event editor" : "Sleppa einföldum atburðaritli",
    "Show week numbers" : "Sýna vikunúmer",
    "Import calendar" : "Flytja inn dagatal",
    "No Calendars selected for import" : "Engin dagatöl valin til innflutnings",
    "Primary CalDAV address" : "Aðal-CalDAV-vistfang",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-vistfang",
    "Subscribe" : "Gerast áskrifandi"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
